<?php
if ( ! class_exists( 'IPSnot_Admin' )) {

    /**
     * Class for handling administrator page
     */
    class IPSnot_Admin
    {
        /**
         * Show content admin home
         *
         * @return void
         */
        public function index()
        {
            $this->view( 'dashboard' );
        }
        
        /**
         * Show content for create notification
         *
         * @return void
         */
        public function create()
        {
            wp_enqueue_media();
            wp_enqueue_script('wp-color-picker');
            wp_enqueue_style('wp-color-picker');
            
            //Set variable
            $this->notif        = false;
            $this->setting      = new IPSnot_Setting( 0, '__ipsnot-setting' );
            $this->submit_id    = 'ipsnot-create-notif';
            $this->form_id      = 'ipsnot-form-create';
            $this->submit_title = __( 'Create Notification', 'wp_notification_plus' );
            $this->submit_icon  = 'floppy-o';
            $this->page_title   = __( 'Create Notification', 'wp_notification_plus' );
            
            $this->view( 'manage' );
        }
        
        /**
         * Show content for edit notification
         *
         * @return void
         */
        public function edit()
        {
            wp_enqueue_media();
            wp_enqueue_script('wp-color-picker');
            wp_enqueue_style('wp-color-picker');
            
            if ( empty( $_GET['id'] )) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'wp_notification_plus') );
            }
            $id = absint( $_GET['id'] );
            if ( ! $notif = get_post( $id ) ) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'wp_notification_plus') );
            }
            //Set variable
            $this->notif        = $notif;
            $this->setting      = new IPSnot_Setting( $id, '__ipsnot-setting' );
            $this->submit_id    = 'ipsnot-edit-notif';
            $this->form_id      = 'ipsnot-form-update';
            $this->submit_title = __( 'Save Change', 'wp_notification_plus' );
            $this->submit_icon  = 'floppy-o';
            $this->page_title   = __( 'Edit Notification', 'wp_notification_plus' );
            
            $this->view( 'manage' );
        }
        
        /**
         * Show content for setting administrator
         *
         * @return void
         */
        public function setting()
        {
            $this->view( 'setting' );
        }
        
        /**
         * Show content for meta box
         *
         * @return void
         */
        public function meta_box( $post )
        {
        ?>
            <div id="ipsmpop_metaBox">
                <p><strong><?php _e( 'Select Share Object', 'wp_notification_plus' ); ?></strong></p>
                <label for="ipsnot-share" class="screen-reader-text"><?php _e( 'Select Smart Pop', 'wp_notification_plus' ); ?></label>
                <select name="ipsnot_id" id="ipsnot-share">
                    <option value="0"><?php _e( 'None', 'wp_notification_plus' ); ?></option>
                    <?php
                    $current = get_post_meta( $post->ID, '__ipsnot_page_notification', true );
                    $notifs  = $this->_get_notif_objects();
                    if ( ! empty( $notifs )) 
                    {
                        foreach( $notifs as $notif ) 
                        {
                            $sltd = '';
                            if ( $notif->ID == $current ) {
                                $sltd = ' selected="selected"';
                            }
                            echo '<option value="' . $notif->ID . '"' . $sltd . '>' . $notif->post_title . '</option>';
                        }
                    }
                    ?>
                </select>
                <?php wp_nonce_field( plugin_basename( __FILE__ ), 'ipsnot_mbox_nonce' ); ?>
            </div>
        <?php
        }
        
        /**
         * Get admin view file
         *
         * @param string $filename
         * @return void
         */
        public function view( $filename )
        {
            $path  = IPSNOT_PATH . 'app/views/admin/';
            $path .= strtolower( $filename ) . '.php'; 
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Admin header template
         *
         * @param string $page
         * @return void
         */
        public function header( $page, $title = '', $info = '', $icon = '' )
        {
            $struct = array(
                'ipsnot' => array(
                    'title'     => __( 'Dashboard', 'wp_notification_plus' ),
                    'info'      => __( 'See all notification and manage it', 'wp_notification_plus' ),
                    'icon'      => 'dashboard'
                ),
                'ipsnot-create' => array(
                    'title'     => __( 'Create Notification', 'wp_notification_plus' ),
                    'info'      => __( 'Create new notification for your visitor', 'wp_notification_plus' ),
                    'icon'      => 'plus-circle'
                ),
                'ipsnot-setting' => array(
                    'title'     => __( 'Settings', 'wp_notification_plus' ),
                    'info'      => __( 'Set the notification settings', 'wp_notification_plus' ),
                    'icon'      => 'cog'
                )
            );
        ?>
            <div class="ipbe-top">
                <div class="ipbe-header">
                    <div class="ipbe-page-title">
                        <h1>
                            <i class="ibe ibe-bell"></i>
                            <span>
                                <strong><span>WP</span> Special Notification</strong>
                                <em><?php _e( 'WordPress plugin to create special notification for your visitors','wp_notification_plus' ); ?></em>
                            </span>
                        </h1>
                    </div>
                </div>
                <div class="ipbe-nav">
                    <ul>
                    <?php
                    if ( array_key_exists( $page, $struct ))
                    {
                        if ( empty( $title )) {
                            $title = $struct[$page]['title'];
                        }
                        if ( empty( $info )) {
                            $info  = $struct[$page]['info'];
                        }
                        if ( empty( $icon )) {
                            $icon  = $struct[$page]['icon'];
                        }
                    }
                    foreach( $struct as $name => $data ) 
                    {
                        $active = '';
                        if ( $page == $name ) {
                            $active = ' class="active"';
                        }
                        echo '<li' . $active . '>' .
                                '<a href="admin.php?page=' . $name . '">' .
                                    '<i class="ibe ibe-' . $data['icon'] . '"></i>' .
                                    $data['title'] .
                                '</a>' .
                            '</li>';
                    }
                    ?>
                    </ul>
                </div>
                <div class="ipbe-page-info">
                    <i class="ibe ibe-<?php echo $icon; ?>"></i>
                    <div class="ipbe-info">
                        <h2><?php echo $title; ?></h2>
                        <h3><?php echo $info; ?></h3>
                    </div>
                </div>
            </div>
        <?php
        }
        
        /**
         * Get notif objects
         *
         * @return array
         */
        protected function _get_notif_objects()
        {
            $args = array(
                'orderby'        => 'post_title',
                'order'          => 'DESC', 
                'post_type'      => 'ipsnot-item',
                'post_status'    => array('publish'),
                'posts_per_page' => -1,
                'paged'          => 1
            );
            $query  = new WP_Query;
            $shares = $query->query( $args );
            return $shares;
        }
    }
}