<?php
if ( ! class_exists( 'IPSnot_Factory' )) {

    /**
     * Class for create share
     */
    class IPSnot_Factory
    {
        /**
         * Notification Object
         *
         * @var object
         */
        protected $_notif;
        
        /**
         * Notification Object setting
         *
         * @var object
         */
        protected $_setting;
         
        /**
         * Class construct
         *
         * @return void
         */
        public function __construct( $setting = false )
        {
            if ( ! $setting ) 
            {
                $notifId = 0;
                if ( $notif = $this->_get_notif_object() ) {
                    $notifId = $notif->ID;
                }
                $this->notif       = $notif;
                $this->chats       = $this->_get_chats( $notif );
                $this->setting     = new IPSnot_Setting( $notifId, '__ipsnot-setting' );
                $this->type        = $this->setting->getSetting( 'type' );
                $this->is_show     = $this->_is_show();
                $this->is_preview  = false;
            } else 
            {
                $notif = false;
                $chats = array();
                if ( ! empty( $_POST['notifid'] )) 
                {
                    $notifid = absint( $_POST['notifid'] );
                    $notif   = get_post( $notifid );
                    $chats   = $this->_get_chats( $notif );
                }
                $this->notif       = $notif;
                $this->chats       = $chats;
                $this->setting     = $setting;
                $this->is_show     = true;
                $this->is_preview  = true;
                $this->type        = $this->setting->getSetting( 'type' );
            }
        }
        
        /**
         * Get setting
         *
         * @return object
         */
        public function setting()
        {
            return $this->setting;
        }
        
        /**
         * Is show
         *
         * @return object
         */
        public function is_show()
        {
            return $this->is_show;
        }
        
        /**
         * Render notif
         *
         * @return void
         */
        public function render()
        {
            if ( ! $this->is_show() ) {
                return false;
            }
            $this->_get_widget();
        }
        
        /**
         * Get admin view file
         *
         * @param string $filename
         * @return void
         */
        public function view( $filename )
        {
            $path  = IPSNOT_PATH . 'app/views/public/';
            $path .= strtolower( $filename ) . '.php'; 
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Get notification widget
         *
         * @return void
         */
        protected function _get_widget()
        {
            if ( $this->type == 'call' ){
                $this->view( 'call' );
            } else {
                $this->view( 'chat' );
            }
        }
        
        /**
         * Get notif object
         *
         * @return object
         */
        protected function _get_notif_object()
        {
            global $post;
            
            $notifId = 0;
            $notif   = false;
            $general = get_option( '__ipsnot_general_notification' );
            if ( ! empty( $general )) {
                $notifId = absint( $general );
            } else 
            {
                if ( ( is_page() || is_single() ) && ! empty( $post )) {
                    $notifId = get_post_meta( $post->ID, '__ipsnot_page_notification', true );
                } elseif ( is_home() ) {
                    $notifId = get_option( '__ipsnot_home_notification' );
                }
            }
            if ( ! empty( $notifId )) {
                $notif = get_post( $notifId );
            }
            return $notif;
        }
        
        /**
         * Check is notif object showing
         *
         * @return object
         */
        protected function _is_show()
        {
            if ( ! $this->notif || $this->notif->post_status != 'publish' ) {
                return false;
            }
            $opt_key    = 'restricted_' . $this->_type;
            $restricted = $this->setting()->getSetting( $opt_key, 'false' );
            if ( $restricted == 'true' )
            {
                global $user_ID;
                if ( empty( $user_ID )) {
                    return false;
                }
            }
            return true;
        }
        
        /**
         * Get chat contents
         *
         * @param  object $notif
         * @return object
         */
        protected function _get_chats( $notif )
        {
            $chats = array();
            if ( ! empty( $notif ))
            {
                $args  = array(
                    'orderby'        => 'ID',
                    'order'          => 'ASC', 
                    'post_type'      => 'ipsnot-chat-item',
                    'post_status'    => array('publish','draft'),
                    'posts_per_page' => -1,
                    'paged'          => 1,
                    'post_parent'    => $notif->ID
                );
                $query  = new WP_Query;
                $chats  = $query->query( $args );
            }
            return $chats;
        }
    }
}