<?php
/*
Plugin Name: WP Notification Plus - Lite
Plugin URI: 
Description: Plugin that is used to make a notification in your website that can read easily your website visitor
Version: 1.0
Author: InstaPRoduct
Author URI: http://insta-product.com/
*/

/*
    LICENSE: This source file to be part of a system developed by InstaPRoduct. 
    All copyrights use this file and the code in it owned by InstaPRoduct. 
    It is strictly forbidden to use, copy, modify or distribute this file and 
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPSNOT_TITLE', 'WP Notification Plus - Lite' );
define( 'IPSNOT_FILE', __FILE__ );
define( 'IPSNOT_PATH', plugin_dir_path( __FILE__ ) );
define( 'IPSNOT_BASE_URL', plugin_dir_url( __FILE__ ) );

require_once( IPSNOT_PATH . "app/setting.php" );
require_once( IPSNOT_PATH . "app/ajax.php" );
require_once( IPSNOT_PATH . "app/faicon.php" );
require_once( IPSNOT_PATH . "app/list.php" );
require_once( IPSNOT_PATH . "app/model.php" );
require_once( IPSNOT_PATH . "app/admin.php" );
require_once( IPSNOT_PATH . "app/font.php" );
require_once( IPSNOT_PATH . "app/factory.php" );

/*
require_once( IPSNOT_PATH . "app/form.php" ); */

/**
 * Main class
 */
if ( ! class_exists( 'IPSnot' )) {

    class IPSnot
    {
        /**
         * Setup Plugin
         */
        public static function setup()
        {
            $hook = sanitize_title( IPSNOT_TITLE );
            
            add_action( 'init', array( __CLASS__, 'i18n' ) );
            
            //Plugin init
            add_action( 'admin_init', array( __CLASS__, 'admin_init' ) );
            
            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'add_admin_menu' ) );
            
            // Add meta box option
            add_action( 'add_meta_boxes', array( __CLASS__, 'add_meta_box' ) );
            add_action( 'save_post', array( __CLASS__, 'save_page_share' ) );
            
            //Add share object to site
            add_action( 'wp_footer', array( __CLASS__, 'factory' ) );
            
            //Add admin style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'admin_style_global' ), 1000 );
            add_action( 'admin_print_styles-toplevel_page_ipsnot', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipsnot-create', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipsnot-setting', array( __CLASS__, 'admin_style' ), 1000 );
            
            add_action( 'admin_print_scripts-toplevel_page_ipsnot', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipsnot-create', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipsnot-setting', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts', array( __CLASS__, 'global_admin_script' ), 1100 );
            
            //Front style & script
            add_action('wp_head', array( __CLASS__, 'public_style' ) );
            
            if ( ! is_admin() ) {
                add_action('wp_enqueue_scripts', array( __CLASS__, 'public_script' ), 10 );
            }
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public static function add_admin_menu()
        {
            add_menu_page( 
                IPSNOT_TITLE, 
                IPSNOT_TITLE, 
                'ipsnot_manage', 
                'ipsnot',
                array( __CLASS__, 'admin' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'ipsnot',
                __( 'Dashboard', 'wp_notification_plus' ), 
                __( 'Dashboard', 'wp_notification_plus' ), 
                'ipsnot_manage', 
                'ipsnot',
                array( __CLASS__, 'admin' )
            );
            add_submenu_page( 
                'ipsnot',
                __( 'Create Notification', 'wp_notification_plus' ), 
                __( 'Create Notification', 'wp_notification_plus' ), 
                'ipsnot_manage', 
                'ipsnot-create',
                array( __CLASS__, 'admin_create' )
            );
        }
        
        /**
         * Handle internationalization
         *
         * @return void
         */
        public static function i18n()
        {
            load_plugin_textdomain( 'wp_notification_plus', false, basename( IPSNOT_PATH ) . '/languages/' );
        }
        
        /**
         * Admin Init
         *
         * @return void
         */
        public static function admin_init()
        {
            global $wp_roles;
            
            /** 
             * Register Roles
             */
            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'ipsnot_manage' );
            
            $wp_roles->reinit();
            
            /**
             * Ajax handler
             **/
            $ajax = new IPSnot_Ajax();
            $ajax->exec();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public static function admin()
        {
            $display = new IPSnot_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->edit();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator create notification
         *
         * @return void
         */
        public static function admin_create()
        {
            $display = new IPSnot_Admin();
            $display->create();
        }
        
        /**
         * Share factory
         *
         * @return void
         */
        public static function factory()
        {
            global $ipsnot_notif;
            
            if ( ! $ipsnot_notif ) {
                $ipsnot_notif = new IPSnot_Factory();
            }
            $ipsnot_notif->render();
        }
        
        /**
         * Add administrator meta box
         *
         * @return void
         */
        public static function add_meta_box()
        {
            $screens = array( 'post', 'page' );
            foreach ($screens as $screen) {
                add_meta_box(
                    'ipsnot_metabox',
                    __( 'Notification Settings', 'wp_notification_plus' ),
                    array( __CLASS__, 'meta_box_content' ),
                    $screen,
                    'side'
                );
            }
        }
        
        /**
         * Content for administrator meta box
         *
         * @return void
         */
        public static function meta_box_content( $post )
        {
            $display = new IPSnot_Admin();
            $display->meta_box( $post );
        }
        
        /**
         * Save page/post meta box setting
         *
         * @return void
         */
        public static function save_page_share( $post_id )
        {
            if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {
                if ( ! current_user_can( 'edit_page', $post_id ) ) {
                    return;
                }
            } else {
                if ( ! current_user_can( 'edit_post', $post_id ) ) {
                    return;
                }
            }
            // Check if the user intended to change this value.
            if ( ! isset( $_POST['ipsnot_mbox_nonce'] ) ) {
                return;
            }
            $post_ID = $_POST['post_ID'];
            $notifId = sanitize_text_field( $_POST['ipsnot_id'] );
            update_post_meta( $post_ID, '__ipsnot_page_notification', $notifId );
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style()
        {
            wp_deregister_style('insta-backend-style');
            wp_register_style('insta-backend-style', plugin_dir_url( __FILE__ ) . 'css/ipbe-admin.css', false, null);
            wp_enqueue_style('insta-backend-style');
            
            wp_deregister_style('ipsnot-admin-style');
            wp_register_style('ipsnot-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('ipsnot-admin-style');
            
            wp_deregister_style('ipsnot-public-style');
            wp_register_style('ipsnot-public-style', plugin_dir_url( __FILE__ ) . 'css/public.css', false, null);
            wp_enqueue_style('ipsnot-public-style');
            
            wp_deregister_style('daterangepicker');
            wp_register_style('daterangepicker', plugin_dir_url( __FILE__ ) . 'js/daterangepicker/daterangepicker-bs3.css', false, null);
            wp_enqueue_style('daterangepicker');
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style_global()
        {
            wp_deregister_style('ipsnot-admin-style-global');
            wp_register_style('ipsnot-admin-style-global', plugin_dir_url( __FILE__ ) . 'css/admin-global.css', false, null);
            wp_enqueue_style('ipsnot-admin-style-global');
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public static function admin_script($hook)
        {
        ?>
        <script type="text/javascript">
            var ipsnot_img_url  = '<?php echo IPSNOT_BASE_URL . 'img/'; ?>',
                ipbe_base       = '<?php echo IPSNOT_BASE_URL; ?>',
                ip_ui_message   = 
                {
                    delete_confirm_title: '<?php _e( 'Delete Confirmation', 'wp_notification_plus' ); ?>',
                    delete_confirm_info: '<?php _e( 'Are you sure doing this action?', 'wp_notification_plus' ); ?>'
                },
                ipsnot_favicon_base = '<?php echo IPSNOT_BASE_URL . 'img/favicon/'; ?>';
        </script>
        <?php
            wp_deregister_script('insta-backend-script');
            wp_enqueue_script(
                'insta-backend-script',
                plugin_dir_url( __FILE__ ) . 'js/ipbe-admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('ipsnot-admin-script');
            wp_enqueue_script(
                'ipsnot-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('moment');
            wp_enqueue_script(
                'moment',
                plugin_dir_url( __FILE__ ) . 'js/daterangepicker/moment.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('daterangepicker');
            wp_enqueue_script(
                'daterangepicker',
                plugin_dir_url( __FILE__ ) . 'js/daterangepicker/daterangepicker.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print Global Admin Script
         *
         * @return void
         */
        public static function global_admin_script($hook)
        {
            wp_deregister_script('ipsnot-admin-global-script');
            wp_enqueue_script(
                'ipsnot-admin-global-script',
                plugin_dir_url( __FILE__ ) . 'js/admin-global.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print public style
         *
         * @return void
         */
        public static function public_style()
        {
            global $ipsnot_notif;
            
            if ( ! $ipsnot_notif ) {
                $ipsnot_notif = new IPSnot_Factory();
            }
            $setting = $ipsnot_notif->setting();
            $name    = $setting->getSetting( 'font_family', 'roboto' );
            $fonts   = IPSnot_Font::getLinks();
            if ( array_key_exists( $name, $fonts )) 
            {
                $family  = $fonts[$name];
                $fontUrl = 'http://fonts.googleapis.com/css?family=' . $family;
                echo '<link id="ipsnot-font" href="' . $fontUrl . '" rel="stylesheet" type="text/css">';
            }
            $type      = $setting->getSetting( 'type', 'chat' );
            $wdelay    = $setting->getSetting( 'widget_delay_' . $type, 5 );
            $wduration = $setting->getSetting( 'widget_duration_' . $type, 0 );
            $wmethod   = $setting->getSetting( 'widget_delay_method_' . $type, 'page' );
            $animspeed = $setting->getSetting( 'animation_speed_' . $type, 'md' );
            $audio     = $setting->getSetting( 'audio_' . $type, 0 );
            $tab_title = $setting->getSetting( 'tab_title_' . $type, __( 'Notification', 'wp_notification_plus' ));
            $tab_icon  = $setting->getSetting( 'tab_icon_' . $type );
            $tab_i_url = IPSNOT_BASE_URL . 'img/favicon/' . $tab_icon . '.ico';
        ?>
            <script type="text/javascript">
                var ipsnot_ajaxurl = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
                var ipsnot_options = {
                    'browser_title': "<?php echo $tab_title; ?>",
                    'browser_icon': "<?php echo $tab_i_url; ?>",
                    'widget_delay': "<?php echo absint( $wdelay ); ?>",
                    'widget_duration': "<?php echo absint( $wduration ); ?>",
                    'widget_method': "<?php echo $wmethod; ?>",
                    'animation_speed': "<?php echo $animspeed; ?>",
                    'widget_audio': "<?php echo $audio; ?>",
                    
                    <?php
                    //Variable chat
                    if ( $type == 'chat' ) 
                    {
                        echo '"chat_delay": "' . $setting->getSetting( 'chat_delay', 4 ) . '",';
                        echo '"ringtone": "' . $setting->getSetting( 'chat_ringtone', '' ) . '",';
                    }
                    ?>
                };
            </script>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/public.css" rel="stylesheet">
        <?php
        }

        /**
         * Print public script
         *
         * @return void
         */
        public static function public_script()
        {
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
            
            wp_deregister_script('ipsnot-public-script');
            wp_enqueue_script(
                'ipsnot-public-script',
                plugin_dir_url( __FILE__ ) . 'js/public.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }
    }

}
//Run plugin
IPSnot::setup();
?>