<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPSnot_Ajax' )) {

    class IPSnot_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            'ipsnot_update'            => 'update',
            'ipsnot_delete'            => 'delete',
            'ipsnot_setting'           => 'setting',
            'ipsnot_chat_update'       => 'chat_update',
            'ipsnot_chat_delete'       => 'chat_delete',
            'ipsnot_chat_get_edit'     => 'chat_get_edit',
            'ipsnot_get_preview'       => 'get_preview',
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['ipsnot'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Update
         *
         * @return void
         */
        public function update()
        {
            $redirect = false;
            $is_add   = false;
            $error    = true;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['notifid'] )) {
                $notifId = absint( $_POST['notifid'] );
                if ( $notif = get_post( $notifId ) ) {
                    $this->_update_notif( $notif );
                } else {
                    $notifId = 0;
                }
            } else {
                $notifId = $this->_add_notif();
            }
            if ( $notifId )
            {
                $error = false;
                $model = new IPSnot_Model();
                $model->save_setting( $notifId );
            }
            if ( $error ) {
                $status  = 0;
                $notifId  = 0;
                if ( $is_add ) {
                    $message = __( 'Failed to create a notification.', 'wp_notification_plus' );
                } else {
                    $message = __( 'Failed to save notification.', 'wp_notification_plus' );
                }
            } else {
                $status = 1;
                if ( $is_add ) {
                    $message  = __( 'Successfully create a notification.', 'wp_notification_plus' );
                    $redirect = admin_url() . 'admin.php?page=ipsnot&create=1';
                } else {
                    $message = __( 'Successfully to save notification.', 'wp_notification_plus' );
                }
            }
            $result = array(
                'status'   => $status,
                'message'  => $message,
                'notifid'  => $notifId
            );
            if ( $redirect ) {
                $result['redirect'] = $redirect;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Add new notif page
         *
         * @return int
         */
        protected function _add_notif()
        {
            global $user_ID;
            
            $suffix     = '_' . $_POST['type'];
            $title_key  = 'title' . $suffix;
            $status_key = 'status' . $suffix;
            
            if ( empty( $_POST[$title_key] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST[$title_key] );
            }
            if ( $_POST[$status_key] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            $dataPost = array(
                'post_status'  => $status, 
                'post_type'    => 'ipsnot-item', 
                'post_author'  => $user_ID,
                'post_title'   => $title,
                'post_content' => ''
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update notif page
         *
         * @param  object $notif
         * @return boolean
         */
        protected function _update_notif( $notif )
        {
            $suffix     = '_' . $_POST['type'];
            $title_key  = 'title' . $suffix;
            $status_key = 'status' . $suffix;
            
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST[$title_key] ) && $_POST[$title_key] != $notif->post_title ) {
                $dataPost['post_title'] = apply_filters( 'single_post_title', $_POST[$title_key] );
            }
            if ( $_POST[$status_key] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            if ( $status != $notif->post_status ) {
                $dataPost['post_status'] = $status;
            }
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $notif->ID;
                $result = wp_update_post( $dataPost );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete object
         *
         * @return void
         */
        public function delete()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp_notification_plus' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the notification', 'wp_notification_plus' ),
                    'redirect' => admin_url() . 'admin.php?page=ipsnot&delete=1'
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the notification', 'wp_notification_plus' )
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for save setting
         *
         * @return void
         */
        public function setting()
        {
            $error = false;
            if ( isset( $_POST['home_notification'] )) {
                $this->_save_setting( 'home_notification' );
            }
            if ( isset( $_POST['general_notification'] )) {
                $this->_save_setting( 'general_notification' );
            }
            if ( $error ) {
                $status = 0;
                $msg    = __( 'Failed to update notification settings.', 'wp_notification_plus' );
            } else {
                $status = 1;
                $msg    = __( 'Successfully to update notification settings.', 'wp_notification_plus' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $msg
            ) );
            die();
        }
        
        /**
         * Save setting
         *
         * @param  string $name
         * @return boolean
         */
        protected function _save_setting( $name )
        {
            if ( ! empty( $_POST[$name] ))
            {
                $notifId = absint( $_POST[$name] );
                if ( $notif = get_post( $notifId ))
                {
                    update_option( '__ipsnot_' . $name, $notifId );
                }
            } else {
                update_option( '__ipsnot_' . $name, 0 );
            }
            return true;
        }
        
        /**
         * Update chat
         *
         * @return void
         */
        public function chat_update()
        {
            $notifId = 0;
            if ( ! empty( $_POST['notif_id'] )) {
                $notifId = absint( $_POST['notif_id'] );
            }
            if ( ! $notif = get_post( $notifId )) 
            {
                $notifId = $this->_add_notif();
                $notif   = get_post( $notifId );
            }
            $redirect = false;
            $is_add   = false;
            $error    = true;
            $ohtml    = false;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['content_chat_id'] )) {
                $chatId = absint( $_POST['content_chat_id'] );
                if ( $chat = get_post( $chatId ) ) {
                    $this->_update_chat( $chat );
                } else {
                    $chatId = 0;
                }
            } else {
                $chatId = $this->_add_chat( $notif );
            }
            if ( $chatId )
            {
                $error = false;
                $model = new IPSnot_Model();
                $model->save_chat_setting( $chatId );
            }
            if ( $error ) {
                $status   = 0;
                $chatId  = 0;
                if ( $is_add ) {
                    $message = __( 'Failed to create a chat content.', 'wp_notification_plus' );
                } else {
                    $message = __( 'Failed to save chat content.', 'wp_notification_plus' );
                }
            } else {
                $status = 1;
                if ( $is_add ) 
                {
                    $message = __( 'Successfully create a chat content.', 'wp_notification_plus' );
                    $chat    = get_post( $chatId );
                    $ohtml   = $this->_get_chat_list_item( $chat );
                } 
                else {
                    $message = __( 'Successfully to save chat item.', 'wp_notification_plus' );
                }
            }
            $result = array(
                'status'   => $status,
                'message'  => $message,
                'chatid'   => $chatId,
                'notifid'  => $notifId
            );
            if ( $ohtml ) {
                $result['chat'] = $ohtml;
            }
            if ( ! empty( $chatId )) 
            {
                $chat = get_post( $chatId );
                $result['content'] = $this->_get_chat_item_text( $chat );
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Add new chat item
         *
         * @param  object $notif
         * @return int
         */
        protected function _add_chat( $notif )
        {
            global $user_ID;
            
            $title    = 'Chat in ' . date( 'd F Y, h:i:s' );
            $status   = 'publish';
            $dataPost = array(
                'post_status'  => $status, 
                'post_type'    => 'ipsnot-chat-item', 
                'post_author'  => $user_ID,
                'post_title'   => $title,
                'post_content' => $_POST['content'],
                'post_parent'  => $notif->ID
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update chat item
         *
         * @param  object $chat
         * @return boolean
         */
        protected function _update_chat( $chat )
        {
            $result    = 0;
            $data_post = array();
            if ( ! empty( $_POST['content'] ) && $_POST['content'] != $chat->post_content ) {
                $data_post['post_content'] = $_POST['content'];
            }
            if ( ! empty( $data_post )) {
                $data_post['ID'] = $chat->ID;
                $result = wp_update_post( $data_post );
            }
            return $result;
        }
        
        /**
         * Get chat list item 
         *
         * @param  object $chat
         * @return boolean
         */
        protected function _get_chat_list_item( $chat )
        { 
            $item = '';
            $path  = IPSNOT_PATH . 'app/views/admin/manage/content_chat/chat.php'; 
            if ( file_exists( $path )) 
            {
                ob_start();
                $this->chat = $chat;
                include( $path );
                $item = ob_get_clean();
            }
            return $item;
        }
        
        /**
         * Get chat list item text
         *
         * @param  object $chat
         * @return boolean
         */
        protected function _get_chat_item_text( $chat )
        { 
            $text = '';
            $path  = IPSNOT_PATH . 'app/views/admin/manage/content_chat/chat_text.php'; 
            if ( file_exists( $path )) 
            {
                ob_start();
                $this->chat = $chat;
                include( $path );
                $text = ob_get_clean();
            }
            return $text;
        }
        
        /**
         * Processing ajax for delete chat item
         *
         * @return void
         */
        public function chat_delete()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp_notification_plus' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the chat item', 'wp_notification_plus' )
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the chat item', 'wp_notification_plus' )
                ) );
            }
            die();
        }
        
        /**
         * Get form edit chat
         *
         * @return void
         */
        public function chat_get_edit()
        {
            if ( ! empty( $_GET['id'] )) {
                $chatId = absint( $_GET['id'] );
                if ( $chat = get_post( $chatId ))
                {
                    $this->content = $chat;
                    $path  = IPSNOT_PATH . 'app/views/admin/manage/content_chat/form.php'; 
                    if ( file_exists( $path )) {
                        include( $path );
                    }
                    die();
                }
            }
            echo '';
            die();
        }
        
        /**
         * Get admin view file
         *
         * @param string $filename
         * @return void
         */
        public function view( $filename )
        {
            $path  = IPSNOT_PATH . 'app/views/admin/';
            $path .= strtolower( $filename ) . '.php';
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Get widget preview content
         *
         * @return void
         */
        public function get_preview()
        {
            //Create object setting
            $setting = new IPSnot_Setting( 0, '__ipsnot-setting' );
            $setting->addSettings( $_POST );
            
            //Create preview
            $factory = new IPSnot_Factory( $setting );
            $factory->render();
            die();
        }
    }
}